@@ -20,6 +20,7 @@
 #include <KPackage/Package>
 #include <KPackage/PackageLoader>
 #include <Plasma/PluginLoader>
+#include <plasmaquick/appletquickitem.h>
 
 class ViewerCorona : public Plasma::Corona
 {
@@ -54,11 +55,10 @@ private:
     View *m_view;
 };
 
-View::View(ViewerCorona *cor, bool konsoleVisible, QWindow *parent)
+View::View(ViewerCorona *cor, QWindow *parent)
     : PlasmaQuick::ContainmentView(cor, parent)
 {
     cor->setView(this);
-    m_konsoleVisible = konsoleVisible;
     engine()->rootContext()->setContextProperty("desktop", this);
     setSource(QUrl::fromLocalFile(cor->kPackage().filePath("views", "Desktop.qml")));
 }
@@ -70,8 +70,8 @@ View::~View()
 void View::resizeEvent(QResizeEvent *event)
 {
     emit corona()->screenGeometryChanged(0);
-    emit corona()->availableScreenRectChanged();
-    emit corona()->availableScreenRegionChanged();
+    emit corona()->availableScreenRectChanged(0);
+    emit corona()->availableScreenRegionChanged(0);
     PlasmaQuick::ContainmentView::resizeEvent(event);
 }
 
@@ -108,11 +108,12 @@ void View::addApplet(const QString &applet)
         a = Plasma::PluginLoader::self()->loadApplet(metadataPath);
 
         // Load translations from KPackage files if bundled
-        const QString localePath = a->kPackage().filePath("translations");
+        // TODO: what to do in KF6?
+        /*const QString localePath = a->kPackage().filePath("translations");
         if (!localePath.isEmpty()) {
             const QString localeDomain = QByteArray("plasma_applet_") + a->pluginMetaData().pluginId();
             KLocalizedString::addDomainLocaleDir(localeDomain.toLatin1(), localePath);
-        }
+        }*/
 
         containment()->addApplet(a);
     }
@@ -242,7 +243,8 @@ void View::emitExternalData(const QString &data)
 
     Plasma::Applet *applet = containment()->applets().constFirst();
 
-    QObject *graphicsObject = qobject_cast<QQuickItem *>(applet->property("_plasma_graphicObject").value<QObject *>());
+    PlasmaQuick::AppletQuickItem *graphicsObject = PlasmaQuick::AppletQuickItem::itemForApplet(applet);
+
     if (!graphicsObject) {
         return;
     }
@@ -250,11 +252,6 @@ void View::emitExternalData(const QString &data)
     QMetaObject::invokeMethod(graphicsObject, "externalData", Q_ARG(QString, QString()), Q_ARG(QVariant, data));
 }
 
-bool View::konsoleVisible()
-{
-    return m_konsoleVisible;
-}
-
 void View::changeLocation(int location)
 {
     QString locationType = "floating";
